# AutoKitteh Python SDK

This is the Python SDK for [AutoKitteh](https://autokitteh.com).

Currently, this library provides only the `activity` decorator.
See more at [the docs](https://docs.autokitteh.com).

## Installing

Installing is required only for local testing,
when AutoKitteh runs your workflow it'll automatically install this library.

```
python -m pip install autokitteh
```
